..
      Copyright 2010 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

================================================
Welcome to Dashboard, the Murano Project Web UI!
================================================

Dashboard is a project that provides Web UI to Murano Project.

This document describes Murano Dashboard for contributors of the project, and assumes
that you are already familiar with Murano from an `end-user perspective`_.

.. _`end-user perspective`: http://murano.readthedocs.org/

This documentation is generated by the Sphinx toolkit and lives in the source
tree.

Installation Guide
==================
Install
-------
1. Check out sources to some directory (*<home>/murano-dashboard*)::

    user@work:~/$ git clone git://git.openstack.org/openstack/murano-dashboard

2. Install virtualenv::

    user@work:~/$ cd murano-dashboard && sudo python ./tools/install_venv.py

Configure
---------
1. Copy configuration file from template::

    user@work:~/$ cp murano-dashboard/muranodashboard/local/local_settings.py.example murano-dashboard/muranodashboard/local/local_settings.py

2. Open configuration file for editing::

    user@work:~/$ cd murano-dashboard/muranodashboard/local/ && nano local_settings.py

2. Configure according to you environment::

    ...
    SECRET_KEY = 'some_random_value'
    ...
    OPENSTACK_HOST = "localhost"
    ...

Run
----
Run Dashboard in virtualenv::

    user@work:~/$ cd murano-dashboard && sudo ./tools/with_venv.sh python manage.py runserver 0.0.0.0:8080
